@@ -4,6 +4,8 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+// NOLINTBEGIN(misc-const-correctness) due to QFETCH
+
 #include <Akonadi/Item>
 #include <KCalendarCore/Event>
 #include <QObject>
@@ -32,7 +34,7 @@ private Q_SLOTS:
     {
         QFETCH(QString, mimeType);
 
-        QByteArray serialized =
+        QByteArray const serialized =
             "BEGIN:VCALENDAR\n"
             "PRODID:-//K Desktop Environment//NONSGML libkcal 3.5//EN\n"
             "VERSION:2.0\n"
@@ -85,7 +87,7 @@ private Q_SLOTS:
 
         const QDate currentDate = QDate::currentDate();
 
-        Event::Ptr event = Event::Ptr(new Event());
+        Event::Ptr const event = Event::Ptr(new Event());
         event->setUid(QStringLiteral("12345"));
         event->setDtStart(QDateTime(currentDate, {}));
         event->setDtEnd(QDateTime(currentDate.addDays(1), {}));
@@ -112,11 +114,13 @@ private Q_SLOTS:
 
         auto event2 = item2.payload<Event::Ptr>();
         QVERIFY(event2 != nullptr);
-        QVERIFY(event2->summary().toUtf8() == QByteArray(utf_umlaut));
-        QVERIFY(event2->summary().toLatin1() == QByteArray(latin1_umlaut));
+        QCOMPARE(event2->summary().toUtf8(), QByteArray(utf_umlaut));
+        QCOMPARE(event2->summary().toLatin1(), QByteArray(latin1_umlaut));
     }
 };
 
 QTEST_MAIN(KCalCoreSerializerTest)
 
+// NOLINTEND(misc-const-correctness)
+
 #include "kcalcoreserializertest.moc"
