@@ -91,21 +91,21 @@ QVariant CalendarModel::entityData(const Akonadi::Item &item, int column, int ro
             return inc->dateTime(KCalendarCore::Incidence::RoleEndTimeZone).toString();
 
         case DateTimeDue:
-            if (KCalendarCore::Todo::Ptr t = CalendarUtils::todo(item)) {
+            if (KCalendarCore::Todo::Ptr const t = CalendarUtils::todo(item)) {
                 return t->dtDue().toString();
             } else {
                 return {};
             }
 
         case Priority:
-            if (KCalendarCore::Todo::Ptr t = CalendarUtils::todo(item)) {
+            if (KCalendarCore::Todo::Ptr const t = CalendarUtils::todo(item)) {
                 return t->priority();
             } else {
                 return {};
             }
 
         case PercentComplete:
-            if (KCalendarCore::Todo::Ptr t = CalendarUtils::todo(item)) {
+            if (KCalendarCore::Todo::Ptr const t = CalendarUtils::todo(item)) {
                 return t->percentComplete();
             } else {
                 return {};
@@ -130,21 +130,21 @@ QVariant CalendarModel::entityData(const Akonadi::Item &item, int column, int ro
             return inc->dateTime(KCalendarCore::Incidence::RoleEndTimeZone).toUTC();
 
         case DateTimeDue:
-            if (KCalendarCore::Todo::Ptr t = CalendarUtils::todo(item)) {
+            if (KCalendarCore::Todo::Ptr const t = CalendarUtils::todo(item)) {
                 return t->dtDue().toUTC();
             } else {
                 return {};
             }
 
         case Priority:
-            if (KCalendarCore::Todo::Ptr t = CalendarUtils::todo(item)) {
+            if (KCalendarCore::Todo::Ptr const t = CalendarUtils::todo(item)) {
                 return t->priority();
             } else {
                 return {};
             }
 
         case PercentComplete:
-            if (KCalendarCore::Todo::Ptr t = CalendarUtils::todo(item)) {
+            if (KCalendarCore::Todo::Ptr const t = CalendarUtils::todo(item)) {
                 return t->percentComplete();
             } else {
                 return {};
