@@ -24,7 +24,7 @@ using namespace Qt::Literals::StringLiterals;
 
 using namespace Akonadi;
 
-QString proposalComment(const KCalendarCore::Incidence::Ptr &incidence)
+static QString proposalComment(const KCalendarCore::Incidence::Ptr &incidence)
 {
     QString comment;
 
@@ -141,7 +141,7 @@ ITIPHandlerHelper::SendResult ITIPHandlerHelper::sentInvitation(int messageBoxRe
         // Yes, we do modify the incidence here, but we still keep the Ptr
         // semantics, because this change is only for sending and not stored int the
         // local calendar.
-        KCalendarCore::Incidence::Ptr _incidence(incidence->clone());
+        KCalendarCore::Incidence::Ptr const _incidence(incidence->clone());
         if (_incidence->summary().isEmpty()) {
             _incidence->setSummary(xi18n("<placeholder>No summary given</placeholder>"));
         }
@@ -257,7 +257,7 @@ void ITIPHandlerHelper::slotIncidenceCreatedDialogClosed(int messageBoxReturnCod
                                                          KCalendarCore::iTIPMethod method,
                                                          const KCalendarCore::Incidence::Ptr &incidence)
 {
-    ITIPHandlerHelper::SendResult status = sentInvitation(messageBoxReturnCode, incidence, method);
+    ITIPHandlerHelper::SendResult const status = sentInvitation(messageBoxReturnCode, incidence, method);
     Q_EMIT sendIncidenceCreatedMessageFinished(status, method, incidence);
 }
 
@@ -273,13 +273,11 @@ bool ITIPHandlerHelper::handleIncidenceAboutToBeModified(const KCalendarCore::In
                 "Do you really want to edit it?");
             const int messageBoxReturnCode = KMessageBox::warningTwoActions(mParent, question, {}, KStandardGuiItem::ok(), KStandardGuiItem::cancel());
             return messageBoxReturnCode != KMessageBox::ButtonCode::SecondaryAction;
-            break;
         }
         case KCalendarCore::Incidence::TypeJournal:
         case KCalendarCore::Incidence::TypeTodo:
             // Not sure why we handle to-dos differently regarding this
             return true;
-            break;
         default:
             qCritical() << "Unknown incidence type: " << incidence->type() << incidence->typeStr();
             Q_ASSERT_X(false, "ITIPHandlerHelper::handleIncidenceAboutToBeModified()", "Unknown incidence type");
@@ -318,11 +316,6 @@ void ITIPHandlerHelper::sendIncidenceModifiedMessage(KCalendarCore::iTIPMethod m
             return;
         }
     } else if (incidence->type() == KCalendarCore::Incidence::TypeTodo) {
-        if (method == KCalendarCore::iTIPRequest) {
-            // This is an update to be sent to the organizer
-            method = KCalendarCore::iTIPReply;
-        }
-
         const QString question = i18n(
             "Do you want to send a status update to the "
             "organizer of this task?");
@@ -334,7 +327,6 @@ void ITIPHandlerHelper::sendIncidenceModifiedMessage(KCalendarCore::iTIPMethod m
         return;
     } else if (incidence->type() == KCalendarCore::Incidence::TypeEvent) {
         if (attendeeStatusChanged && method == KCalendarCore::iTIPRequest) {
-            method = KCalendarCore::iTIPReply;
             const QString question = i18n(
                 "Your status as an attendee of this event changed. "
                 "Do you want to send a status update to the event organizer?");
@@ -361,7 +353,7 @@ void ITIPHandlerHelper::slotIncidenceModifiedDialogClosed(int messageBoxReturnCo
                                                           KCalendarCore::iTIPMethod method,
                                                           const KCalendarCore::Incidence::Ptr &incidence)
 {
-    ITIPHandlerHelper::SendResult status = sentInvitation(messageBoxReturnCode, incidence, method);
+    ITIPHandlerHelper::SendResult const status = sentInvitation(messageBoxReturnCode, incidence, method);
     Q_EMIT sendIncidenceModifiedMessageFinished(status, method, incidence);
 }
 
@@ -402,11 +394,6 @@ void ITIPHandlerHelper::sendIncidenceDeletedMessage(KCalendarCore::iTIPMethod me
             return;
         }
     } else if (incidence->type() != KCalendarCore::Incidence::TypeEvent) {
-        if (method == KCalendarCore::iTIPRequest) {
-            // This is an update to be sent to the organizer
-            method = KCalendarCore::iTIPReply;
-        }
-
         const QString question = (incidence->type() == KCalendarCore::Incidence::TypeTodo) ? i18n(
                                                                                                  "Do you want to send a status update to the "
                                                                                                  "organizer of this task?")
@@ -430,7 +417,7 @@ void ITIPHandlerHelper::sendIncidenceDeletedMessage(KCalendarCore::iTIPMethod me
         }
 
         if (incidenceAcceptedBefore) {
-            QString question = i18n(
+            QString const question = i18n(
                 "You had previously accepted an invitation to this event. "
                 "Do you want to send an updated response to the organizer "
                 "declining the invitation?");
@@ -459,29 +446,30 @@ void ITIPHandlerHelper::slotIncidenceDeletedDialogClosed(const int messageBoxRet
                                                          KCalendarCore::iTIPMethod method,
                                                          const KCalendarCore::Incidence::Ptr &incidence)
 {
-    ITIPHandlerHelper::SendResult status = sentInvitation(messageBoxReturnCode, incidence, method);
+    ITIPHandlerHelper::SendResult const status = sentInvitation(messageBoxReturnCode, incidence, method);
     Q_EMIT sendIncidenceDeletedMessageFinished(status, method, incidence);
 }
 
-ITIPHandlerHelper::SendResult
-ITIPHandlerHelper::sendCounterProposal(const QString &receiver, const KCalendarCore::Incidence::Ptr &oldEvent, const KCalendarCore::Incidence::Ptr &newEvent)
+ITIPHandlerHelper::SendResult ITIPHandlerHelper::sendCounterProposal(const QString &receiver,
+                                                                     const KCalendarCore::Incidence::Ptr &oldIncidence,
+                                                                     const KCalendarCore::Incidence::Ptr &newIncidence)
 {
-    Q_ASSERT(oldEvent);
-    Q_ASSERT(newEvent);
+    Q_ASSERT(oldIncidence);
+    Q_ASSERT(newIncidence);
 
-    if (!oldEvent || !newEvent || *oldEvent == *newEvent) {
+    if (!oldIncidence || !newIncidence || *oldIncidence == *newIncidence) {
         return ITIPHandlerHelper::ResultNoSendingNeeded;
     }
 
     if (CalendarSettings::self()->outlookCompatCounterProposals()) {
-        KCalendarCore::Incidence::Ptr tmp(oldEvent->clone());
-        tmp->setSummary(i18n("Counter proposal: %1", newEvent->summary()));
-        tmp->setDescription(newEvent->description());
-        tmp->addComment(proposalComment(newEvent));
+        KCalendarCore::Incidence::Ptr const tmp(oldIncidence->clone());
+        tmp->setSummary(i18n("Counter proposal: %1", newIncidence->summary()));
+        tmp->setDescription(newIncidence->description());
+        tmp->addComment(proposalComment(newIncidence));
 
         return sentInvitation(KMessageBox::ButtonCode::PrimaryAction, tmp, KCalendarCore::iTIPReply, receiver);
     } else {
-        return sentInvitation(KMessageBox::ButtonCode::PrimaryAction, newEvent, KCalendarCore::iTIPCounter, receiver);
+        return sentInvitation(KMessageBox::ButtonCode::PrimaryAction, newIncidence, KCalendarCore::iTIPCounter, receiver);
     }
 }
 
